# source('reroot.R')

# ape を読み込む
library(ape)

# インファイル名を変数に格納する
inFile.name <- ("MyTree.tre")

# アウトグループを設定する
outGroup <- "Human"

# tree をインファイルから読み込む
MyTree <- read.tree(inFile.name)

# プリントアウトに必要なデバイスを用意する．
image.file <- paste(inFile.name, "rerooted.pdf", sep = "") 
pdf(image.file) 
# 一つの PDF ファイルに二つの tree を並べる
layout(matrix(1:2,1,2))


# 系統樹を書いたときに，上にルートが来るようにする
# MyTree <- ladderize(MyTree,FALSE)
MyTree <- ladderize(MyTree)
## 樹長なしで Tree をプロットする．
plot(MyTree,use.edge.length = FALSE)

# BS 値をのせる
#nodelabels(t$node.label)

## 実は root では根幹 3 分岐になって rooting される訳ではない．
# 下にあるように，is.rooted(rerooted) と打つと，FALSE と帰ってくる．
# rerooted <- root(MyTree,"Human")
# is.rooted(rerooted)
## そこで，以下のようにすると，根幹 2 分岐になる．
# PDF ファイルでは 3 分岐に見えるが，Newick などで保存して
rerooted <- root(MyTree,outGroup,r=T)
rerooted <- ladderize(rerooted)
plot(rerooted,use.edge.length = FALSE)

# rerooted をテキストで保存する．
# Phylip 形式．
#write.tree(rerooted, file="MyTree.trererooted.nwk")  
# Nexus 形式
#write.nexus(rerooted, file="MyNexusTreefile.nex")

# dev.off という関数でデバイスを閉じる．
dev.off()